@@ -8,8 +8,7 @@ var searchData=
   ['databar_2eidl',['DataBar.idl',['../DataBar_8idl.html',1,'']]],
   ['databaraxis_2eidl',['DataBarAxis.idl',['../DataBarAxis_8idl.html',1,'']]],
   ['databarentrytype_2eidl',['DataBarEntryType.idl',['../DataBarEntryType_8idl.html',1,'']]],
-  ['database_2eidl',['Database.idl',['../fieldmaster_2Database_8idl.html',1,'']]],
-  ['database_2eidl',['Database.idl',['../textfield_2Database_8idl.html',1,'']]],
+  ['database_2eidl',['Database.idl',['../fieldmaster_2Database_8idl.html',1,'(Global Namespace)'],['../textfield_2Database_8idl.html',1,'(Global Namespace)']]],
   ['databaseaccess_2eidl',['DatabaseAccess.idl',['../DatabaseAccess_8idl.html',1,'']]],
   ['databaseaccessconnection_2eidl',['DatabaseAccessConnection.idl',['../DatabaseAccessConnection_8idl.html',1,'']]],
   ['databaseaccesscontext_2eidl',['DatabaseAccessContext.idl',['../DatabaseAccessContext_8idl.html',1,'']]],
@@ -100,6 +99,8 @@ var searchData=
   ['datapilottables_2eidl',['DataPilotTables.idl',['../DataPilotTables_8idl.html',1,'']]],
   ['datapilottablesenumeration_2eidl',['DataPilotTablesEnumeration.idl',['../DataPilotTablesEnumeration_8idl.html',1,'']]],
   ['datapoint_2eidl',['DataPoint.idl',['../DataPoint_8idl.html',1,'']]],
+  ['datapointcustomlabelfield_2eidl',['DataPointCustomLabelField.idl',['../DataPointCustomLabelField_8idl.html',1,'']]],
+  ['datapointcustomlabelfieldtype_2eidl',['DataPointCustomLabelFieldType.idl',['../DataPointCustomLabelFieldType_8idl.html',1,'']]],
   ['datapointgeometry3d_2eidl',['DataPointGeometry3D.idl',['../DataPointGeometry3D_8idl.html',1,'']]],
   ['datapointlabel_2eidl',['DataPointLabel.idl',['../DataPointLabel_8idl.html',1,'']]],
   ['datapointproperties_2eidl',['DataPointProperties.idl',['../DataPointProperties_8idl.html',1,'']]],
@@ -113,25 +114,18 @@ var searchData=
   ['dataseries_2eidl',['DataSeries.idl',['../DataSeries_8idl.html',1,'']]],
   ['datasettings_2eidl',['DataSettings.idl',['../DataSettings_8idl.html',1,'']]],
   ['datasink_2eidl',['DataSink.idl',['../DataSink_8idl.html',1,'']]],
-  ['datasource_2eidl',['DataSource.idl',['../sdb_2DataSource_8idl.html',1,'']]],
-  ['datasource_2eidl',['DataSource.idl',['../chart2_2data_2DataSource_8idl.html',1,'']]],
+  ['datasource_2eidl',['DataSource.idl',['../chart2_2data_2DataSource_8idl.html',1,'(Global Namespace)'],['../sdb_2DataSource_8idl.html',1,'(Global Namespace)']]],
   ['datasourceadministrationdialog_2eidl',['DatasourceAdministrationDialog.idl',['../DatasourceAdministrationDialog_8idl.html',1,'']]],
   ['datasourcebrowser_2eidl',['DataSourceBrowser.idl',['../DataSourceBrowser_8idl.html',1,'']]],
   ['datatransferevent_2eidl',['DataTransferEvent.idl',['../DataTransferEvent_8idl.html',1,'']]],
   ['datatruncation_2eidl',['DataTruncation.idl',['../DataTruncation_8idl.html',1,'']]],
   ['datatype_2eidl',['DataType.idl',['../DataType_8idl.html',1,'']]],
   ['datatypeclass_2eidl',['DataTypeClass.idl',['../DataTypeClass_8idl.html',1,'']]],
-  ['date_2eidl',['Date.idl',['../offapi_2com_2sun_2star_2util_2Date_8idl.html',1,'']]],
-  ['date_2eidl',['Date.idl',['../udkapi_2com_2sun_2star_2bridge_2oleautomation_2Date_8idl.html',1,'']]],
-  ['date_2eidl',['Date.idl',['../offapi_2com_2sun_2star_2xsd_2Date_8idl.html',1,'']]],
+  ['date_2eidl',['Date.idl',['../udkapi_2com_2sun_2star_2bridge_2oleautomation_2Date_8idl.html',1,'(Global Namespace)'],['../offapi_2com_2sun_2star_2util_2Date_8idl.html',1,'(Global Namespace)'],['../offapi_2com_2sun_2star_2xsd_2Date_8idl.html',1,'(Global Namespace)']]],
   ['datecondition_2eidl',['DateCondition.idl',['../DateCondition_8idl.html',1,'']]],
   ['datedisplayformat_2eidl',['DateDisplayFormat.idl',['../DateDisplayFormat_8idl.html',1,'']]],
-  ['datefield_2eidl',['DateField.idl',['../component_2DateField_8idl.html',1,'']]],
-  ['datefield_2eidl',['DateField.idl',['../control_2DateField_8idl.html',1,'']]],
-  ['datetime_2eidl',['DateTime.idl',['../presentation_2textfield_2DateTime_8idl.html',1,'']]],
-  ['datetime_2eidl',['DateTime.idl',['../text_2textfield_2DateTime_8idl.html',1,'']]],
-  ['datetime_2eidl',['DateTime.idl',['../util_2DateTime_8idl.html',1,'']]],
-  ['datetime_2eidl',['DateTime.idl',['../xsd_2DateTime_8idl.html',1,'']]],
+  ['datefield_2eidl',['DateField.idl',['../component_2DateField_8idl.html',1,'(Global Namespace)'],['../control_2DateField_8idl.html',1,'(Global Namespace)']]],
+  ['datetime_2eidl',['DateTime.idl',['../presentation_2textfield_2DateTime_8idl.html',1,'(Global Namespace)'],['../text_2textfield_2DateTime_8idl.html',1,'(Global Namespace)'],['../util_2DateTime_8idl.html',1,'(Global Namespace)'],['../xsd_2DateTime_8idl.html',1,'(Global Namespace)']]],
   ['datetimerange_2eidl',['DateTimeRange.idl',['../DateTimeRange_8idl.html',1,'']]],
   ['datetimeshape_2eidl',['DateTimeShape.idl',['../DateTimeShape_8idl.html',1,'']]],
   ['datetimewithtimezone_2eidl',['DateTimeWithTimezone.idl',['../DateTimeWithTimezone_8idl.html',1,'']]],
@@ -139,17 +133,14 @@ var searchData=
   ['datewithtimezone_2eidl',['DateWithTimezone.idl',['../DateWithTimezone_8idl.html',1,'']]],
   ['day_2eidl',['Day.idl',['../Day_8idl.html',1,'']]],
   ['dbaseconnectionproperties_2eidl',['DBASEConnectionProperties.idl',['../DBASEConnectionProperties_8idl.html',1,'']]],
-  ['dde_2eidl',['DDE.idl',['../fieldmaster_2DDE_8idl.html',1,'']]],
-  ['dde_2eidl',['DDE.idl',['../textfield_2DDE_8idl.html',1,'']]],
+  ['dde_2eidl',['DDE.idl',['../fieldmaster_2DDE_8idl.html',1,'(Global Namespace)'],['../textfield_2DDE_8idl.html',1,'(Global Namespace)']]],
   ['ddeiteminfo_2eidl',['DDEItemInfo.idl',['../DDEItemInfo_8idl.html',1,'']]],
   ['ddelink_2eidl',['DDELink.idl',['../DDELink_8idl.html',1,'']]],
   ['ddelinkinfo_2eidl',['DDELinkInfo.idl',['../DDELinkInfo_8idl.html',1,'']]],
   ['ddelinkmode_2eidl',['DDELinkMode.idl',['../DDELinkMode_8idl.html',1,'']]],
   ['ddelinks_2eidl',['DDELinks.idl',['../DDELinks_8idl.html',1,'']]],
   ['ddelinksenumeration_2eidl',['DDELinksEnumeration.idl',['../DDELinksEnumeration_8idl.html',1,'']]],
-  ['decimal_2eidl',['Decimal.idl',['../offapi_2com_2sun_2star_2xsd_2Decimal_8idl.html',1,'']]],
-  ['decimal_2eidl',['Decimal.idl',['../udkapi_2com_2sun_2star_2bridge_2oleautomation_2Decimal_8idl.html',1,'']]],
-  ['decryptor_2eidl',['Decryptor.idl',['../Decryptor_8idl.html',1,'']]],
+  ['decimal_2eidl',['Decimal.idl',['../udkapi_2com_2sun_2star_2bridge_2oleautomation_2Decimal_8idl.html',1,'(Global Namespace)'],['../offapi_2com_2sun_2star_2xsd_2Decimal_8idl.html',1,'(Global Namespace)']]],
   ['defaultbackend_2eidl',['DefaultBackend.idl',['../DefaultBackend_8idl.html',1,'']]],
   ['defaultcomponentinspectormodel_2eidl',['DefaultComponentInspectorModel.idl',['../DefaultComponentInspectorModel_8idl.html',1,'']]],
   ['defaulted_2eidl',['Defaulted.idl',['../Defaulted_8idl.html',1,'']]],
@@ -161,16 +152,14 @@ var searchData=
   ['defaultnumberingprovider_2eidl',['DefaultNumberingProvider.idl',['../DefaultNumberingProvider_8idl.html',1,'']]],
   ['defaultprovider_2eidl',['DefaultProvider.idl',['../DefaultProvider_8idl.html',1,'']]],
   ['defaultregistry_2eidl',['DefaultRegistry.idl',['../DefaultRegistry_8idl.html',1,'']]],
-  ['defaults_2eidl',['Defaults.idl',['../drawing_2Defaults_8idl.html',1,'']]],
-  ['defaults_2eidl',['Defaults.idl',['../text_2Defaults_8idl.html',1,'']]],
+  ['defaults_2eidl',['Defaults.idl',['../drawing_2Defaults_8idl.html',1,'(Global Namespace)'],['../text_2Defaults_8idl.html',1,'(Global Namespace)']]],
   ['defaultviewcontroller_2eidl',['DefaultViewController.idl',['../DefaultViewController_8idl.html',1,'']]],
   ['deferrability_2eidl',['Deferrability.idl',['../Deferrability_8idl.html',1,'']]],
   ['definitioncontainer_2eidl',['DefinitionContainer.idl',['../DefinitionContainer_8idl.html',1,'']]],
   ['definitioncontent_2eidl',['DefinitionContent.idl',['../DefinitionContent_8idl.html',1,'']]],
   ['dependencyexception_2eidl',['DependencyException.idl',['../DependencyException_8idl.html',1,'']]],
   ['dependenttextfield_2eidl',['DependentTextField.idl',['../DependentTextField_8idl.html',1,'']]],
-  ['deploymentexception_2eidl',['DeploymentException.idl',['../offapi_2com_2sun_2star_2deployment_2DeploymentException_8idl.html',1,'']]],
-  ['deploymentexception_2eidl',['DeploymentException.idl',['../udkapi_2com_2sun_2star_2uno_2DeploymentException_8idl.html',1,'']]],
+  ['deploymentexception_2eidl',['DeploymentException.idl',['../udkapi_2com_2sun_2star_2uno_2DeploymentException_8idl.html',1,'(Global Namespace)'],['../offapi_2com_2sun_2star_2deployment_2DeploymentException_8idl.html',1,'(Global Namespace)']]],
   ['description_2eidl',['Description.idl',['../Description_8idl.html',1,'']]],
   ['descriptor_2eidl',['Descriptor.idl',['../Descriptor_8idl.html',1,'']]],
   ['desktop_2eidl',['Desktop.idl',['../Desktop_8idl.html',1,'']]],
@@ -178,8 +167,7 @@ var searchData=
   ['desktoptasks_2eidl',['DesktopTasks.idl',['../DesktopTasks_8idl.html',1,'']]],
   ['devicecapability_2eidl',['DeviceCapability.idl',['../DeviceCapability_8idl.html',1,'']]],
   ['deviceinfo_2eidl',['DeviceInfo.idl',['../DeviceInfo_8idl.html',1,'']]],
-  ['diagram_2eidl',['Diagram.idl',['../Diagram_8idl.html',1,'']]],
-  ['diagram_2eidl',['Diagram.idl',['../_2Diagram_8idl.html',1,'']]],
+  ['diagram_2eidl',['Diagram.idl',['../Diagram_8idl.html',1,'(Global Namespace)'],['../_2Diagram_8idl.html',1,'(Global Namespace)']]],
   ['dialogclosedevent_2eidl',['DialogClosedEvent.idl',['../DialogClosedEvent_8idl.html',1,'']]],
   ['dialogprovider_2eidl',['DialogProvider.idl',['../DialogProvider_8idl.html',1,'']]],
   ['dialogprovider2_2eidl',['DialogProvider2.idl',['../DialogProvider2_8idl.html',1,'']]],
@@ -226,7 +214,6 @@ var searchData=
   ['documentindexmark_2eidl',['DocumentIndexMark.idl',['../DocumentIndexMark_8idl.html',1,'']]],
   ['documentindexmarkasian_2eidl',['DocumentIndexMarkAsian.idl',['../DocumentIndexMarkAsian_8idl.html',1,'']]],
   ['documentindexparagraphstyles_2eidl',['DocumentIndexParagraphStyles.idl',['../DocumentIndexParagraphStyles_8idl.html',1,'']]],
-  ['documentiologring_2eidl',['DocumentIOLogRing.idl',['../DocumentIOLogRing_8idl.html',1,'']]],
   ['documentmacroconfirmationrequest_2eidl',['DocumentMacroConfirmationRequest.idl',['../DocumentMacroConfirmationRequest_8idl.html',1,'']]],
   ['documentmspasswordrequest_2eidl',['DocumentMSPasswordRequest.idl',['../DocumentMSPasswordRequest_8idl.html',1,'']]],
   ['documentmspasswordrequest2_2eidl',['DocumentMSPasswordRequest2.idl',['../DocumentMSPasswordRequest2_8idl.html',1,'']]],
@@ -236,10 +223,7 @@ var searchData=
   ['documentrevisionlistpersistence_2eidl',['DocumentRevisionListPersistence.idl',['../DocumentRevisionListPersistence_8idl.html',1,'']]],
   ['documentsaverequest_2eidl',['DocumentSaveRequest.idl',['../DocumentSaveRequest_8idl.html',1,'']]],
   ['documentscriptlibrarycontainer_2eidl',['DocumentScriptLibraryContainer.idl',['../DocumentScriptLibraryContainer_8idl.html',1,'']]],
-  ['documentsettings_2eidl',['DocumentSettings.idl',['../sheet_2DocumentSettings_8idl.html',1,'']]],
-  ['documentsettings_2eidl',['DocumentSettings.idl',['../presentation_2DocumentSettings_8idl.html',1,'']]],
-  ['documentsettings_2eidl',['DocumentSettings.idl',['../drawing_2DocumentSettings_8idl.html',1,'']]],
-  ['documentsettings_2eidl',['DocumentSettings.idl',['../text_2DocumentSettings_8idl.html',1,'']]],
+  ['documentsettings_2eidl',['DocumentSettings.idl',['../drawing_2DocumentSettings_8idl.html',1,'(Global Namespace)'],['../presentation_2DocumentSettings_8idl.html',1,'(Global Namespace)'],['../sheet_2DocumentSettings_8idl.html',1,'(Global Namespace)'],['../text_2DocumentSettings_8idl.html',1,'(Global Namespace)']]],
   ['documentsignatureinformation_2eidl',['DocumentSignatureInformation.idl',['../DocumentSignatureInformation_8idl.html',1,'']]],
   ['documentstatistic_2eidl',['DocumentStatistic.idl',['../DocumentStatistic_8idl.html',1,'']]],
   ['documentstoremode_2eidl',['DocumentStoreMode.idl',['../DocumentStoreMode_8idl.html',1,'']]],
@@ -258,12 +242,10 @@ var searchData=
   ['drawingdocument_2eidl',['DrawingDocument.idl',['../DrawingDocument_8idl.html',1,'']]],
   ['drawingdocumentdrawview_2eidl',['DrawingDocumentDrawView.idl',['../DrawingDocumentDrawView_8idl.html',1,'']]],
   ['drawingdocumentfactory_2eidl',['DrawingDocumentFactory.idl',['../DrawingDocumentFactory_8idl.html',1,'']]],
-  ['drawpage_2eidl',['DrawPage.idl',['../drawing_2DrawPage_8idl.html',1,'']]],
-  ['drawpage_2eidl',['DrawPage.idl',['../presentation_2DrawPage_8idl.html',1,'']]],
+  ['drawpage_2eidl',['DrawPage.idl',['../drawing_2DrawPage_8idl.html',1,'(Global Namespace)'],['../presentation_2DrawPage_8idl.html',1,'(Global Namespace)']]],
   ['drawpages_2eidl',['DrawPages.idl',['../DrawPages_8idl.html',1,'']]],
   ['drawviewmode_2eidl',['DrawViewMode.idl',['../DrawViewMode_8idl.html',1,'']]],
-  ['driver_2eidl',['Driver.idl',['../Driver_8idl.html',1,'']]],
-  ['driver_2eidl',['Driver.idl',['../_2Driver_8idl.html',1,'']]],
+  ['driver_2eidl',['Driver.idl',['../Driver_8idl.html',1,'(Global Namespace)'],['../_2Driver_8idl.html',1,'(Global Namespace)']]],
   ['drivermanager_2eidl',['DriverManager.idl',['../DriverManager_8idl.html',1,'']]],
   ['driverpropertyinfo_2eidl',['DriverPropertyInfo.idl',['../DriverPropertyInfo_8idl.html',1,'']]],
   ['dropcapformat_2eidl',['DropCapFormat.idl',['../DropCapFormat_8idl.html',1,'']]],
